@@ -1,7 +1,7 @@
 package Daje::Workflow::Database;
 use Mojo::Base -base, -signatures;
 
-use Mojo::Pg;
+
 use Mojo::Loader qw(load_class);
 
 # NAME
@@ -40,7 +40,7 @@ use Mojo::Loader qw(load_class);
 # janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
 #
 
-our $VERSION = "0.10";
+our $VERSION = "0.12";
 
 has 'pg';
 has 'migrations';
@@ -49,11 +49,9 @@ sub migrate($self) {
 
     my $length = scalar @{$self->migrations};
     for (my $i = 0; $i < $length; $i++) {
-        my $class = @{$self->migrations}[$i]->{class};
-        my $cl = load_class $class;
-        $class->import();
+        my $cl = load_class @{$self->migrations}[$i]->{class};
         $self->pg->migrations->name(@{$self->migrations}[$i]->{name})->from_data(
-            $class, @{$self->migrations}[$i]->{name}
+            @{$self->migrations}[$i]->{class}, @{$self->migrations}[$i]->{name}
         )->migrate(@{$self->migrations}[$i]->{migration});
     }
 
@@ -136,6 +134,7 @@ __END__
 
 
 
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
@@ -168,7 +167,7 @@ Daje::Workflow::Database is the Database migrate plugin for Daje::Workflow
 
 =head1 REQUIRES
 
-L<Mojo::Pg> 
+L<Mojo::Loader> 
 
 L<Mojo::Base> 
 
